diff --git a/.gitattributes b/.gitattributes
index a3f5e05ded0b6b428a13c2b84e6488f461d4fee2..1586863acee146da6e65f8edbd867b4fcfc10a8d 100644
--- a/.gitattributes
+++ b/.gitattributes
@@ -31,7 +31,6 @@ dist/style_prive.html -text
 dist/win_width.htc -text
 ecrire/action/autoriser.php -text
 ecrire/action/dater.php -text
-ecrire/action/documenter.php -text
 ecrire/action/editer_article.php -text
 ecrire/action/editer_auteurs.php -text
 ecrire/action/editer_mot.php -text
@@ -44,6 +43,7 @@ ecrire/action/instituer_forum.php -text
 ecrire/action/instituer_langue_rubrique.php -text
 ecrire/action/instituer_syndic.php -text
 ecrire/action/joindre.php -text
+ecrire/action/legender.php -text
 ecrire/action/logout.php -text
 ecrire/action/petitionner.php -text
 ecrire/action/poster.php -text
@@ -100,7 +100,6 @@ ecrire/exec/convert_utf8.php -text
 ecrire/exec/dater.php -text
 ecrire/exec/delete_all.php -text
 ecrire/exec/discuter.php -text
-ecrire/exec/documenter.php -text
 ecrire/exec/documents_liste.php -text
 ecrire/exec/editer_auteurs.php -text
 ecrire/exec/editer_mot.php -text
@@ -113,6 +112,7 @@ ecrire/exec/import_all.php -text
 ecrire/exec/informer.php -text
 ecrire/exec/install.php -text
 ecrire/exec/lang_raccourcis.php -text
+ecrire/exec/legender.php -text
 ecrire/exec/memoriser.php -text
 ecrire/exec/message.php -text
 ecrire/exec/message_edit.php -text
diff --git a/ecrire/action/documenter.php b/ecrire/action/legender.php
similarity index 94%
rename from ecrire/action/documenter.php
rename to ecrire/action/legender.php
index d7cc54b960a0d49d200e204f581f898cd7547b80..cb49d19f17822a47416f524df9c88fa747958c44 100644
--- a/ecrire/action/documenter.php
+++ b/ecrire/action/legender.php
@@ -20,8 +20,7 @@ include_spip('inc/actions');
 // spip_register_globals ne fournira donc pas les globales esperees
 // ==> passer par _request() qui simule $_REQUEST sans $_COOKIE
 
-// http://doc.spip.org/@action_documenter_dist
-function action_documenter_dist() {
+function action_legender_dist() {
 	
 	$var_f = charger_fonction('controler_action_auteur', 'inc');
 	$var_f();
@@ -29,7 +28,7 @@ function action_documenter_dist() {
 	$arg = _request('arg');
 
 	if (!preg_match(",^\W*(\d+)$,", $arg, $r)) {
-		 spip_log("action_documenter_dist $arg pas compris");
+		 spip_log("action_legender_dist $arg pas compris");
 	} else {
 
 		$id_document = $r[1];
diff --git a/ecrire/exec/documenter.php b/ecrire/exec/legender.php
similarity index 88%
rename from ecrire/exec/documenter.php
rename to ecrire/exec/legender.php
index 5d6d78b562f2405d0e17e3119a6a0ef136e6c9f8..4049c354db625836c9b1f5f49fb1879618b8b410 100644
--- a/ecrire/exec/documenter.php
+++ b/ecrire/exec/legender.php
@@ -12,8 +12,7 @@
 
 if (!defined("_ECRIRE_INC_VERSION")) return;
 
-// http://doc.spip.org/@exec_documenter_dist
-function exec_documenter_dist()
+function exec_legender_dist()
 {
 	global $id_document, $id, $type, $ancre, $script;
 	$id = intval($id);
@@ -30,6 +29,6 @@ function exec_documenter_dist()
 	include_spip('inc/documents');
 	include_spip('inc/presentation');
 
-	return formulaire_documenter($id_document, array(), $script, $type, $id, $ancre);
+	return formulaire_legender($id_document, array(), $script, $type, $id, $ancre);
 }
 ?>
diff --git a/ecrire/inc/documents.php b/ecrire/inc/documents.php
index 121d3a50d4ad26d2b06048c1db4738b5a1c68639..6215219aa829ffe12a1b8a1d14aa79f90792d1d0 100644
--- a/ecrire/inc/documents.php
+++ b/ecrire/inc/documents.php
@@ -376,7 +376,7 @@ function afficher_portfolio(
 		$res .= formulaire_tourner($id_document, $document, $script, $flag_modif, $type);
 
 		if ($flag_modif)
-		  $res .= formulaire_documenter($id_document, $document, $script, $type, $document["id_$type"], $album);
+		  $res .= formulaire_legender($id_document, $document, $script, $type, $document["id_$type"], $album);
 
 		if (isset($document['info']))
 			$res .= "<div class='verdana1'>".$document['info']."</div>";
@@ -745,7 +745,7 @@ function afficher_case_document($id_document, $id, $script, $type, $deplier = fa
 			  "</font></div>";
 		}
 
-		echo formulaire_documenter($id_document, $document, $script, $type, $id, "document$id_document");
+		echo formulaire_legender($id_document, $document, $script, $type, $id, "document$id_document");
 
 		fin_cadre_enfonce();
 		}
@@ -791,7 +791,7 @@ function afficher_case_document($id_document, $id, $script, $type, $deplier = fa
 		if ($doublon)
 			echo $raccourci_doc;
 
-		echo formulaire_documenter($id_document, $document, $script, $type, $id, "document$id_document");
+		echo formulaire_legender($id_document, $document, $script, $type, $id, "document$id_document");
 		
 		fin_cadre_relief();
 	}
@@ -808,9 +808,7 @@ function teste_doc_deplie($id_document) {
 	return in_array($id_document, $deplies);
 }
 
-
-// http://doc.spip.org/@date_formulaire_documenter
-function date_formulaire_documenter($date, $id_document) {
+function date_formulaire_legender($date, $id_document) {
 
 	if (ereg("([0-9]{4})-([0-9]{2})-([0-9]{2})", $date, $regs)){
 		$mois = $regs[2];
@@ -829,10 +827,9 @@ function date_formulaire_documenter($date, $id_document) {
 // En mode Ajax pour eviter de recharger toute la page ou il se trouve
 // (surtout si c'est un portfolio)
 
-// http://doc.spip.org/@formulaire_documenter
-function formulaire_documenter($id_document, $document, $script, $type, $id, $ancre) {
+function formulaire_legender($id_document, $document, $script, $type, $id, $ancre) {
 
 	// + securite (avec le script exec=documenter ca vient de dehors)
 	if (!preg_match('/^\w+$/',$type, $r)) {
 	  return;
 	}
@@ -897,7 +894,7 @@ function formulaire_documenter($id_document, $document, $script, $type, $id, $an
 	  "<input type='text' name='titre_document' class='formo' value=\"".entites_html($titre).
 	  "\" size='40'	onFocus=\"changeVisible(true, 'valider_doc$id_document', 'block', 'block');\" /><br />\n" .
 	  '<br />' . 
-	  date_formulaire_documenter($date, $id_document) .
+	  date_formulaire_legender($date, $id_document) .
 	  "<br /><b>".
 	  _T('info_description_2').
 	  "</b><br />\n" .
@@ -914,13 +911,13 @@ function formulaire_documenter($id_document, $document, $script, $type, $id, $an
 	  "' type='submit' />" .
 	  "</div>\n";
 
-	$corps = ajax_action_auteur("documenter", $id_document, $script, "show_docs=$id_document&id_$type=$id#$ancre", $corps, "&id_document=$id_document&id=$id&type=$type&ancre=$ancre");
+	$corps = ajax_action_auteur("legender", $id_document, $script, "show_docs=$id_document&id_$type=$id#$ancre", $corps, "&id_document=$id_document&id=$id&type=$type&ancre=$ancre");
 
 	$corps .= 
 	  $vignette .
 	  icone_horizontale(_T('icone_supprimer_document'), redirige_action_auteur('supprimer', "document-$id_document", $script, "id_$type=$id#$ancre"), $supp,  "supprimer.gif", false);
 
-	$bloc = "documenter-aff-$id_document";
+	$bloc = "legender-aff-$id_document";
 
 	$corps = "<div style='text-align:center;height:1%'>"
 		. "<div style='float:".$GLOBALS['spip_lang_left']."'>"
@@ -935,7 +932,7 @@ function formulaire_documenter($id_document, $document, $script, $type, $id, $an
 		. fin_block();
 
 	return ($flag_deplie === 'ajax') ? $corps :
-	   "<div id='documenter-$id_document' class='verdana1' style='color: " . $GLOBALS['couleur_foncee'] . "; border: 1px solid ". $GLOBALS['couleur_foncee'] ."; padding: 5px; margin-top: 3px; background-color: white'>" .
+	   "<div id='legender-$id_document' class='verdana1' style='color: " . $GLOBALS['couleur_foncee'] . "; border: 1px solid ". $GLOBALS['couleur_foncee'] ."; padding: 5px; margin-top: 3px; background-color: white'>" .
 	   $corps .
 	  '</div>';
 }
@@ -829,10 +827,9 @@ function date_formulaire_documenter($date, $id_document) {
 
-	// + securite (avec le script exec=documenter ca vient de dehors)
+	// + securite (avec le script exec=legender ca vient de dehors)
 	if (!preg_match('/^\w+$/',$type, $r)) {
 	  return;